from setuptools import setup, find_packages
import sys, os

version = '0.1'

setup(name='plone.mail',
      version=version,
      description="A package containing a few methods to assist in handling and creating messages with encoded content",
      long_description="""\
""",
      classifiers=[], # Get strings from http://www.python.org/pypi?%3Aaction=list_classifiers
      keywords='Mail Unicode Plone',
      author='Alec Mitchell',
      author_email='apm13@columbia.edu',
      url='http://svn.plone.org/svn/plone/plone.mail',
      license='GPL',
      packages=find_packages(exclude=['ez_setup']),
      namespace_packages=['plone'],
      include_package_data=True,
      zip_safe=True,
      install_requires=[
          'setuptools',
          # -*- Extra requirements: -*-
      ],
      entry_points="""
      # -*- Entry points: -*-
      """,
      )



"""Test library

$Id: test_forms.py 14595 2005-07-12 21:26:12Z philikon $
"""
import unittest

def test_suite():
    from zope.testing.doctestunit import DocTestSuite
    return unittest.TestSuite((
            DocTestSuite('plone.mail'),),)

if __name__ == '__main__':
    unittest.main(defaultTest='test_suite')
